@@ -5,7 +5,7 @@ if (getRversion() >= '2.15.1')
     'Bs.gammas.new', 'N', 'inprod', 'betas', 'ncX', 'X', 'b', 'ncZ', 'Z', 
     'gammas', 'ncW', 'alphas', 'nb', 'Xtime', 'Ztime', 'Xtime.deriv', 'ncX.deriv', 'Ztime.deriv',
     'ncZ.deriv', 'sigma.t', 'logTime', 'Dalphas', 'K', 'Xs', 'Zs', 'Xs.deriv', 'Zs.deriv', 
-    'wk', 'pow', 'st', 'P', 'event', 'id', 'robust', 'sigma.new', 'D.new', 'Bs.gammas','ncW2', 'W2', 'W2s',
+    'wk', 'pow', 'st', 'P', 'event', 'id', 'robust', 'robust.b', 'df.b', 'sigma.new', 'D.new', 'Bs.gammas','ncW2', 'W2', 'W2s',
     'data.id', 'timeVar', 'param', 'TermsX', 'TermsZ', 'formYx', 'formYz', 'WintF.vl',
     'TermsX.deriv', 'TermsZ.deriv', 'extraForm', 'WintF.sl', 'log<-'))
 
