@@ -3,7 +3,7 @@ function (x, estimator = c("both", "mean", "median"), which = NULL, fun = NULL,
         fill.area = FALSE, col.area = "grey", col.abline = "black", col.points = "black", 
         add.last.time.axis.tick = FALSE, include.y = FALSE, main = NULL, xlab = NULL, ylab = NULL, ylab2 = NULL,
         lty = NULL, col = NULL, lwd = NULL, pch = NULL, ask = NULL, legend = FALSE, ..., cex.axis.z = 1, 
-        cex.lab.z = 1) {
+        cex.lab.z = 1, xlim = NULL) {
     estimator <- match.arg(estimator)
     fun <- if (!is.null(fun)) match.fun(fun)
     if (is.null(which))
@@ -86,7 +86,7 @@ function (x, estimator = c("both", "mean", "median"), which = NULL, fun = NULL,
             par(mar = c(5,4,5,4))
             lt <- x$last.time[ii]
             r. <- r[r[, 1] >= lt, ]
-            rng <- range(x$obs.times[[ii]], x$survTimes)
+            rng <- if (is.null(xlim)) range(x$obs.times[[ii]], x$survTimes) else xlim
             plot(x$obs.times[[ii]], x$y[[ii]], xlim = rng, ylim = x$ry,
                 xlab = xlab[i], ylab = ylab2, pch = pch, col = col.points, ...)
             lines(x$fitted.times[[ii]], x$fitted.y[[ii]], col = col, lwd = lwd)
