@@ -45,7 +45,9 @@ function (object, newdata, type = c("Marginal", "Subject"),
         timeVar <- object$timeVar
         interFact <- object$interFact
         robust <- object$robust
+        robust.b <- object$robust.b
         df <- object$df
+        df.b <- object$df.b
         param <- object$param
         extraForm <- object$extraForm
         indFixed <- extraForm$indFixed
